def file_prepend(file, str)
    new_contents = ""
    File.open(file, 'r') do |fd|
        contents = fd.read
        new_contents = str << contents
    end
    # Overwrite file but now with prepended string on it
    File.open(file, 'w') do |fd|
        fd.write(new_contents)
    end
end

namespace :angular do
    desc "Builds the react frontend and moves files into the correct places for deployment."
    task build: :environment do
        # Empty the dist and public folder
        FileUtils.rm_rf("dist/.", secure: true)

        # Do not delete the complete public folder. This would remove other required scripts like OneSignal
        FileUtils.rm_rf("public/main*", secure: true)
        FileUtils.rm_rf("public/polyfills*", secure: true)
        FileUtils.rm_rf("public/runtime*", secure: true)
        FileUtils.rm_rf("public/styles*", secure: true)
        FileUtils.rm_rf("public/vendor*", secure: true)

        # Build the project
        Dir.chdir('frontend') do
            `npm install`

            if ENV["FRONTEND_ENVIRONMENT"] == "production"
                `npm run build-prod`
            else
                `npm run build-dev`
            end
        end

        # Copy the dist to public
        FileUtils.copy_entry "frontend/dist/frontend", "public/"
        #The index.html should not be in the public folder. It will be moved as rails view.
        FileUtils.rm_rf("public/index.html")

        # Move the index out of dist
        FileUtils.mv "frontend/dist/frontend/index.html", "app/views/rechn_mgm_web/documents/index.html.erb"

        file_prepend("app/views/rechn_mgm_web/documents/index.html.erb", "<script>jwt_token = '<%= @token %>'; expire = <%= @expire %>; base_url = '<%= @base_url %>'; connection_type = '<%= @connection_type %>'; </script>")
    end
end
